/**********************************************************************
*
* Copyright (c) 2012-2020 Barbara Geller
* Copyright (c) 2012-2020 Ansel Sermersheim
*
* You may use this file under the terms of the 2-Clause BSD license
* provided with PepperMill or available at:
*
* https://opensource.org/licenses/BSD-2-Clause
*
* PepperMill is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
*
***********************************************************************/

#include "peppermill.h"

#include <stdio.h>

static void showHelp();

int main(int argc, char *argv[])
{
   printf("\n%s\n\n", "** PepperMill - Startup Completed **");

   // passed parameters
   QStringList list;

   for (int k = 0; k < argc; ++k)   {
      QString value = QString::fromUtf8(argv[k]);
      list.append(value);
   }

   try {

      if ( list.size() == 1 || list.at(1) == "--help" ) {
         showHelp();

      } else {

         QString p1 = list.at(1);
         QString p2 = "";
         bool p3    = false;

         if (list.size() > 2) {
            p2 = list.at(2);
         }

         if (list.size() > 3 ) {

            if (list.at(3) == "--f") {
               p3 = true;
            }
         }

         //
         if ( p1 == "--onefile" ) {

            if ( p2.isEmpty() ) {
               printf("%s\n\n","** Pepper Mill - Missing file name");

            } else {
               PepperMill pm(PepperMill::ONEFILE, p2, p3);
               pm.process();
            }

         } else if ( list.at(1) == "--onefolder" ) {

            if ( p2.isEmpty() ) {
               printf("%s\n\n","** Pepper Mill - Missing folder name");

            } else {
               PepperMill pm(PepperMill::ONEFOLDER, p2, p3);
               pm.process();
            }

         } else if ( list.at(1) == "--recursive" ) {

            if ( p2.isEmpty() ) {
               printf("%s\n\n","** Pepper Mill - Missing path name");

            } else {
               PepperMill pm(PepperMill::RECURSIVE, p2, p3);
               pm.process();
            }

         } else {
            showHelp();

         }

      }

   } catch (std::exception &e) {
      // do nothing

   }

   return 0;
}

static void showHelp()
{
   printf("%s\n",             "--help");
   printf("%s \t\t\t\t%s\n\n","--f",          "Force backup overwrite, .h to .cs");

   printf("%s %s  \t\t%s\n",  "--onefile",   "[file name]",   "Convert .h from Qt to Cs, one specified file name");
   printf("%s %s  \t%s\n",    "--onefolder", "[folder name]", "Convert .h from Qt to Cs, specified folder");
   printf("%s %s  \t%s\n\n",  "--recursive", "[path name]",   "Convert .h from Qt to Cs, recrusively specified path");


}
